@@ -27,6 +27,7 @@ typed interactively is started. Use the action "help" to find out about
 available actions.
 """
 
+from dotenv import load_dotenv
 from pkg_resources import iter_entry_points
 from time import sleep
 from waitress.wasyncore import dispatcher
@@ -795,11 +796,15 @@ console -- Run the program in the console.
         interactive_startup = (
             "import os;"
             "os.path.exists(os.environ.get('PYTHONSTARTUP', '')) "
-            "and execfile(os.environ['PYTHONSTARTUP']); del os;"
+            "and %s; del os;"
         )
+        if six.PY2:
+            exec_call = "execfile(os.environ['PYTHONSTARTUP'])"
+        else:
+            exec_call = "exec(open(os.environ['PYTHONSTARTUP']).read())"
         cmdline = self.get_startup_cmd(
             self.options.python,
-            interactive_startup,
+            interactive_startup % exec_call,
             pyflags='-i',
         )
         print('Starting debugger (the name "app" is bound to the top-level '
@@ -942,6 +947,7 @@ def main(args=None):
         options = WSGICtlOptions()
     else:
         options = ZServerCtlOptions()
+
     options.add(name="no_request", short="R", long="no-request", flag=1)
     options.add(name="no_login", short="L", long="no-login", flag=1)
     options.add(name="object_path", short="O:", long="object-path=")
@@ -949,6 +955,13 @@ def main(args=None):
     # Realize arguments and set documentation which is used in the -h option
     options.realize(args, doc=__doc__)
 
+    load_dotenv(os.path.join(options.directory, '..', '..', '.env'))
+
+    if (os.environ.get('PLONE_ENV')):
+        PLONE_ENV = os.environ.get('PLONE_ENV')
+        load_dotenv(os.path.join(options.directory,
+                                 '..', '..', '.env.{}'.format(PLONE_ENV)))
+
     # Run the right command depending on whether we have ZServer
     options.interpreter = os.path.join(options.directory, 'bin', 'interpreter')
     if sys.platform == 'win32':
